@@ -2,7 +2,7 @@
 /*                                                                          */
 /*  The FreeType project -- a free and portable quality TrueType renderer.  */
 /*                                                                          */
-/*  Copyright (C) 1996-2020 by                                              */
+/*  Copyright (C) 1996-2025 by                                              */
 /*  suzuki toshiya, D. Turner, R.Wilhelm, and W. Lemberg                    */
 /*                                                                          */
 /*                                                                          */
@@ -24,17 +24,13 @@
 #endif
 
 #include <ft2build.h>
-#include FT_FREETYPE_H
-#include FT_SFNT_NAMES_H
-#include FT_TRUETYPE_IDS_H
+#include <freetype/freetype.h>
 
-  /* the following header shouldn't be used in normal programs */
-#include FT_INTERNAL_DEBUG_H
+#include <freetype/ftmodapi.h>  /* showing driver name */
+#include <freetype/ftsnames.h>
+#include <freetype/ttnameid.h>
 
-  /* showing driver name */
-#include FT_MODULE_H
-#include FT_INTERNAL_OBJECTS_H
-#include FT_INTERNAL_DRIVER_H
+#include <freetype/internal/ftobjs.h>
 
   /* FSSpec functions are deprecated since Mac OS X 10.4 */
 #ifndef HAVE_FSSPEC
@@ -79,7 +75,7 @@ typedef void FSRef;
 #endif
 #endif
 
-#include FT_MAC_H
+#include <freetype/ftmac.h>
 
 #undef FT_GetFile_From_Mac_Name
 #undef FT_GetFile_From_Mac_ATS_Name
