@@ -2,7 +2,7 @@
 /*                                                                          */
 /*  The FreeType project -- a free and portable quality TrueType renderer.  */
 /*                                                                          */
-/*  Copyright (C) 1996-2024 by                                              */
+/*  Copyright (C) 1996-2025 by                                              */
 /*  D. Turner, R.Wilhelm, and W. Lemberg                                    */
 /*                                                                          */
 /*                                                                          */
@@ -1068,8 +1068,9 @@
 
     num_indices = handle->current_font->num_indices;
 
-    if ( status.offset >= num_indices )
-      status.offset = num_indices - 1;
+    status.offset %= num_indices;
+    if ( status.offset < 0 )
+      status.offset += num_indices;
 
     return 1;
   }
@@ -1829,7 +1830,7 @@
       (*argv)++;
     }
     else
-      status.ptsize = 32 * 64 ;
+      status.ptsize = 32 * 64;
   }
 
 
